---
title: <span class="badge builder"></span> ResourceRef
---
# <span class="badge builder"></span> ResourceRef

## Constructor

```python
ResourceRef()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> accesspolicy.ResourceRef
```

### <span class="badge object-method"></span> kind

```python
def kind(kind: str) -> typing.Self
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ResourceRef](./object-ResourceRef.md)
